package com.ruoyi.base.service;

import java.util.List;
import com.ruoyi.base.domain.RobotOpsAppointmentRecord;

/**
 * 访客预约记录Service接口
 * 
 * @author ruoyi
 * @date 2026-04-28
 */
public interface IRobotOpsAppointmentRecordService 
{
    /**
     * 查询访客预约记录
     * 
     * @param id 访客预约记录主键
     * @return 访客预约记录
     */
    public RobotOpsAppointmentRecord selectRobotOpsAppointmentRecordById(Long id);

    /**
     * 查询访客预约记录列表
     * 
     * @param robotOpsAppointmentRecord 访客预约记录
     * @return 访客预约记录集合
     */
    public List<RobotOpsAppointmentRecord> selectRobotOpsAppointmentRecordList(RobotOpsAppointmentRecord robotOpsAppointmentRecord);

    /**
     * 新增访客预约记录
     * 
     * @param robotOpsAppointmentRecord 访客预约记录
     * @return 结果
     */
    public int insertRobotOpsAppointmentRecord(RobotOpsAppointmentRecord robotOpsAppointmentRecord);

    /**
     * 修改访客预约记录
     * 
     * @param robotOpsAppointmentRecord 访客预约记录
     * @return 结果
     */
    public int updateRobotOpsAppointmentRecord(RobotOpsAppointmentRecord robotOpsAppointmentRecord);

    /**
     * 批量删除访客预约记录
     * 
     * @param ids 需要删除的访客预约记录主键集合
     * @return 结果
     */
    public int deleteRobotOpsAppointmentRecordByIds(Long[] ids);

    /**
     * 删除访客预约记录信息
     * 
     * @param id 访客预约记录主键
     * @return 结果
     */
    public int deleteRobotOpsAppointmentRecordById(Long id);
}
